@@ -35,7 +35,7 @@ EVAL_COMMAND_NAME = 'ep2_eval'
 KEY_UE_NO = 'ue'
 KEY_UE_TAG = 'tag'
 
-__version__ = '0.4.9'
+__version__ = '0.4.11'
 
 def relative_path(basedir, filename):
     """Creates a path relative to base"""
@@ -98,7 +98,7 @@ class Ep2Group:
         return teams
 
     def teams_list(self):
-        csv_file = self.ep2.team_csv(self.name)
+        csv_file = self.team_csv()
         teams = []
 
         with open(csv_file, 'r') as infile:
@@ -192,6 +192,8 @@ class Ep2Group:
         return os.path.join(self.ep2.tutor_repo(), self.name, "exercise_%d.csv" % ue)
 
     def pre_eval_csv(self, ue: int):
+        if self.ep2.ue_type(ue) == ExerciseType.Team:
+            return os.path.join(self.ep2.tutor_repo(), self.name, "ta.csv")
         return os.path.join(self.ep2.tutor_repo(), self.name, "exercise_%d.csv" % ue)
 
     def students_csv(self):
@@ -381,7 +383,7 @@ class Ep2:
         return None
 
     def team_repo(self, path):
-        return os.path.join(self.config.get("Gitlab", "RepoPrefix"), 'team', path).replace("\\", "/")
+        return os.path.join(self.config.get("Gitlab", "RepoPrefix"), 'uebung', path).replace("\\", "/")
 
     def group(self, group: str) -> Ep2Group:
         # TODO add caching
