@@ -183,7 +183,12 @@ def tag(ctx, group, ue: int, late):
     ex_type = ex_test_type(ue)
 
     if ex_type == ExTestType.Team:
-        group.tag_group((TAG_NAME_EX_TEST % ue) if not late else (TAG_NAME_EX_TEST_LATE % ue))
+        teams = list(set([team['team'] for team in group.teams_list()]))
+
+        with click.progressbar(teams, label='Tagging projects', show_eta=True) as bar:
+            for team in bar:
+                ep2.tag_project(ep2.team_repo(team),
+                                (TAG_NAME_EX_TEST % ue) if not late else (TAG_NAME_EX_TEST_LATE % ue))
     else:
         students = group.student_list()
         errors = []
